# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
from .connect_mcp_server_response_event import ConnectMcpServerResponseEvent
import typing
from ...types.mcp_tool import McpTool
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class StreamingResponse(UncheckedBaseModel):
    event: ConnectMcpServerResponseEvent
    message: typing.Optional[str] = None
    tools: typing.Optional[McpTool] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
